@@ -1,6 +1,7 @@
 import abc
 
 import discretisedfield as df
+import numpy as np
 import xarray as xr
 
 
@@ -255,8 +256,8 @@ class AbstractDrive(abc.ABC):
     def to_xarray(self, *args, **kwargs):
         """Export ``micromagneticdata.Drive`` as ``xarray.DataArray``
 
-        The method depends on ``discretisedfield.Field.to_xarray`` and derives the
-        last four dimensions ``x``, ``y``, ``z``, and ``comp`` in the output
+        The method depends on ``discretisedfield.Field.to_xarray`` and derives the last
+        four dimensions ``x``, ``y``, ``z``, and ``comp`` in the output
         ``xarray.DataArray`` from it. The arguments and named arguments to this method
         are passed on to ``discretisedfield.Field.to_xarray``.
 
@@ -264,16 +265,15 @@ class AbstractDrive(abc.ABC):
         change. If the number of stored steps in the ``micromagneticdata.Drive`` are
         more than one, the output contains an extra dimension named after
         ``micromagneticdata.Drive.table.x`` with proper coordinate values. For the case
-        of ``HysteresisDriver``,  the new dimension has four coordinates, namely
-        ``B_hysteresis``, ``Bx_hysteresis``, ``By_hysteresis``, and
-        ``Bz_hysteresis``. The first represents the norm of the hysteresis field, while
-        the rest three represents the components along the respective axes. For a
+        of ``HysteresisDriver``, the new dimension has four coordinates, namely
+        ``B_hysteresis``, ``Bx_hysteresis``, ``By_hysteresis``, and ``Bz_hysteresis``.
+        The first represents the norm of the hysteresis field, while the rest three
+        represents the components along the respective axes. For a
         ``micromagneticdata.Drive`` with a single ``discretisedfield.Field``, the value
         of the single ``discretisedfield.Field.to_xarray`` is returned.
 
         ``micromagneticdata.Drive.info`` is returned as the output ``xarray.DataArray``
-        attributes, besides the ones derived from
-        ``discretisedfield.Field.to_xarray``.
+        attributes, besides the ones derived from ``discretisedfield.Field.to_xarray``.
 
         Parameters
         ----------
@@ -316,8 +316,20 @@ class AbstractDrive(abc.ABC):
         if len(self._step_files) == 1:
             darray = self[0].to_xarray(*args, **kwargs)
         else:
-            field_darrays = (field.to_xarray(*args, **kwargs) for field in self)
-            darray = xr.concat(field_darrays, dim=self.table.data[self.table.x])
+            # xr.stack (below) is too slow and needs twice the amount of memory
+            # field_darrays = (field.to_xarray(*args, **kwargs) for field in self)
+            # darray = xr.concat(field_darrays, dim=self.table.data[self.table.x])
+            array = np.empty(
+                (self.n, *self[0].mesh.n, self[0].dim), dtype=self[0].array.dtype
+            )
+            for i, field in enumerate(self):
+                array[i] = field.array
+            field_0 = self[0].to_xarray(*args, **kwargs)
+            coords = dict(field_0.coords)
+            coords[self.table.x] = self.table.data[self.table.x]
+            darray = xr.DataArray(
+                array, coords=coords, dims=[self.table.x, *field_0.dims]
+            )
             darray[self.table.x].attrs["units"] = self.table.units[self.table.x]
             if self.info["driver"] == "HysteresisDriver":
                 for i in "xyz":
@@ -332,6 +344,8 @@ class AbstractDrive(abc.ABC):
                     darray[f"B{i}_hysteresis"].attrs["units"] = self.table.units[
                         f"B{i}_hysteresis"
                     ]
+            darray.name = field_0.name
+            darray.assign_attrs(**field_0.attrs)
 
         return darray.assign_attrs(**self.info)
 
